import setuptools

# يقرأ ملف الشرح حتى يظهر رابط تليغرام وحساباتك بالموقع
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='abbs',  
    version='0.3',  # هذا التحديث الجديد والمطور
    author='FAIROS',  
    description='Advanced UI and Crypto Library for Termux',
    long_description=long_description,  
    long_description_content_type="text/markdown",  
    packages=setuptools.find_packages(),  
    install_requires=[
        'requests',  
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License"
    ],
    python_requires='>=3.6',
    
    # الروابط الرسمية مالتك اللي تظهر بصفحة المكتبة بالموقع
    project_urls={
        "Official Telegram": "https://t.me/cvvtre",
        "Owner Telegram": "https://t.me/Theyhates_c_P_313",
        "Instagram": "https://www.instagram.com/18k_2008?igsh=MXdoYWx0eXRkc2hxeg==",
    },
)
